#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.active_diagnostic as ad
import emod_api.campaign as camp


class TestAD(TestIntervention):
    """
    Test ActiveDiagnostic intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(ad.ActiveDiagnostic, "ActiveDiagnostic", "camp_ad.json", False)

    def test_all(self):
        camp.set_schema( self.schema )
        trigger_treatment_list = ['Births']
        active_sensitivity = 0.4
        active_specificity = 0.7
        pos_event = 'TBTestPositive'
        treatment_fraction = 0.2
        start_day = 5
        duration = 100
        property_restrictions_list = ["Risk: HIGH"]
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 10
        black_trigger = 'Blackout'
        event_name = 'TB Diagnosis Active Simple'
        intervention_class = "ActiveDiagnostic"
        event = ad.ActiveDiagnostic(camp, trigger_treatment_list, active_sensitivity, active_specificity, pos_event,
                                    treatment_fraction, start_day, duration, property_restrictions_list, nodeIDs,
                                    black_period, black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_ad.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention = ic["Actual_IndividualIntervention_Config"]

        self.assertEqual(intervention["Base_Sensitivity"], active_sensitivity)
        self.assertEqual(intervention["Base_Specificity"], active_specificity)
        self.assertEqual(intervention["Positive_Diagnosis_Event"], pos_event)
        self.assertEqual(intervention["Treatment_Fraction"], treatment_fraction)
        self.assertEqual(intervention["class"], intervention_class)

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in expected_property_restrictions_list])
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(camp.pubsub_signals_pubbing, [pos_event])

    def test_new_intervention_as_file(self, intervention_class_name='ActiveDiagnostic'):
        camp_filename = os.path.join(self.output, 'camp_ad_as_file.json')
        super().new_intervention_as_file_test(ad, camp_filename, intervention_class_name, is_multi=False)


if __name__ == '__main__':
    unittest.main()


